Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 9078)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 9087)
@@ -167,5 +167,5 @@
     ob_class = view.__implemented__.__name__.replace('waeup.kofa.','')
     if fields_string:
-        grok.getSite().logger.info('%s - saved: %s' % (ob_class, fields_string))
+        grok.getSite().logger.info('%s - %s - saved: %s' % (ob_class, view.context.__name__, fields_string))
     return
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/batching.py	(revision 9078)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/batching.py	(revision 9087)
@@ -123,6 +123,7 @@
 
         # Log actions...
+        location_field = self.location_fields[0]
         grok.getSite().logger.info('%s - %s - Record updated: %s'
-            % (self.name, self.location_fields[0], items_changed))
+            % (self.name, row[location_field], items_changed))
         return items_changed
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_batching.py	(revision 9078)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/tests/test_batching.py	(revision 9087)
@@ -103,4 +103,8 @@
         #self.app['faculties']['fac1']['dep1'].certificates['CERT1'].addCertCourse(
         #    self.course, level=100)
+        
+        self.logfile = os.path.join(
+            self.app['datacenter'].storage, 'logs', 'main.log')
+        return
         return
 
@@ -291,4 +295,19 @@
         shutil.rmtree(os.path.dirname(fin_file))
         return
+        
+    def test_import_update_logging(self):
+        self.app['faculties']['FAC2'] = Faculty(code='FAC2')
+        self.app['faculties']['FAC3'] = Faculty(code='FAC3')
+        self.app['faculties']['FAC4'] = Faculty(code='FAC4')
+        num, num_warns, fin_file, fail_file = self.proc.doImport(
+            self.csv_file_faculty_update, FACULTY_HEADER_FIELDS_UPDATE, 'update')
+        self.assertEqual(num_warns,0)
+        logcontent = open(self.logfile).read()
+        # Logging message from updateEntry
+        self.assertTrue(
+            'INFO - system - Department Processor - DEP2 - '
+            'Record updated: local_roles=anne|waeup.local.DepartmentManager, '
+            'code=DEP2'
+            in logcontent)
 
     def test_upload_import_reupload(self):
@@ -403,5 +422,5 @@
             'Not all parents do exist yet. Skipping\r\n'
             )
         # Anne got a local role in department ABC.
         dep = self.app['faculties']['FAC1']['DEP2']
         role_map = IPrincipalRoleMap(dep)
@@ -488,5 +507,5 @@
             'Not all parents do exist yet. Skipping\r\n'
             )
-        # Anne got a local role in course ABC.
+        # Anne got a local role in course CRS2.
         dep = self.app['faculties']['FAC1']['DEP1'].courses['CRS2']
         role_map = IPrincipalRoleMap(dep)
@@ -574,5 +593,5 @@
             'Not all parents do exist yet. Skipping\r\n'
             )
         # Anne got a local role in certificate ABC.
         dep = self.app['faculties']['FAC1']['DEP1'].certificates['CRT2']
         role_map = IPrincipalRoleMap(dep)
@@ -581,4 +600,12 @@
         self.assertEqual(local_role, 'waeup.local.CourseAdviser100')
         shutil.rmtree(os.path.dirname(fin_file))
+        
+        logcontent = open(self.logfile).read()
+        # Logging message from updateEntry
+        self.assertTrue(
+            'INFO - system - Certificate Processor - CRT2 - Record updated: '
+            'local_roles=anne|waeup.local.CourseAdviser100, code=CRT2'
+            in logcontent)        
+        
         return
 
@@ -403,5 +422,5 @@
             'Not all parents do exist yet. Skipping\r\n'
             )
-        # Anne got a local role in department ABC.
+        # Anne got a local role in department DEP2.
         dep = self.app['faculties']['FAC1']['DEP2']
         role_map = IPrincipalRoleMap(dep)
@@ -574,5 +593,5 @@
             'Not all parents do exist yet. Skipping\r\n'
             )
-        # Anne got a local role in certificate ABC.
+        # Anne got a local role in certificate CRT2.
         dep = self.app['faculties']['FAC1']['DEP1'].certificates['CRT2']
         role_map = IPrincipalRoleMap(dep)
